export declare enum Result {
    success = "success",
    failure = "failure",
    running = "running",
    queued = "queued",
    paused = "paused",
    unstable = "unstable",
    aborted = "aborted",
    not_built = "not_built",
    skipped = "skipped",
    unknown = "unknown"
}
export declare function decodeResultValue(resultMaybe: any): Result;
export declare const defaultLayout: {
    nodeSpacingH: number;
    parallelSpacingH: number;
    nodeSpacingV: number;
    nodeRadius: number;
    terminalRadius: number;
    curveRadius: number;
    connectorStrokeWidth: number;
    labelOffsetV: number;
    smallLabelOffsetV: number;
    ypStart: number;
};
export declare type StageType = 'STAGE' | 'PARALLEL' | 'STEP';
/**
 * StageInfo is the input, in the form of an Array<StageInfo> of the top-level stages of a pipeline
 */
export interface StageInfo {
    name: string;
    title: string;
    state: Result;
    completePercent: number;
    id: number;
    type: StageType;
    children: Array<StageInfo>;
    nextSibling?: StageInfo;
    isSequential?: boolean;
    seqContainerName?: string;
}
interface BaseNodeInfo {
    key: string;
    x: number;
    y: number;
    id: number;
    name: string;
    isPlaceholder: boolean;
}
export interface StageNodeInfo extends BaseNodeInfo {
    isPlaceholder: false;
    stage: StageInfo;
}
export interface PlaceholderNodeInfo extends BaseNodeInfo {
    isPlaceholder: true;
    type: 'start' | 'end';
}
export declare type NodeInfo = StageNodeInfo | PlaceholderNodeInfo;
export interface NodeColumn {
    topStage?: StageInfo;
    rows: Array<Array<NodeInfo>>;
    centerX: number;
    hasBranchLabels: boolean;
    startX: number;
}
export interface CompositeConnection {
    sourceNodes: Array<NodeInfo>;
    destinationNodes: Array<NodeInfo>;
    skippedNodes: Array<NodeInfo>;
    hasBranchLabels: boolean;
}
export interface NodeLabelInfo {
    x: number;
    y: number;
    text: string;
    key: string;
    stage?: StageInfo;
    node: NodeInfo;
}
export declare type LayoutInfo = typeof defaultLayout;
/**
 * The result of the graph layout algorithm
 */
export interface PositionedGraph {
    nodeColumns: Array<NodeColumn>;
    connections: Array<CompositeConnection>;
    bigLabels: Array<NodeLabelInfo>;
    smallLabels: Array<NodeLabelInfo>;
    branchLabels: Array<NodeLabelInfo>;
    measuredWidth: number;
    measuredHeight: number;
}
export {};
